import click
import os
from pathlib import Path
from shutil import copytree
import sys
import logging
from typing import Optional, Tuple, List
from bs_pathutils import ensure_path

logger = logging.getLogger("bs_repoman")
logging.basicConfig(level=logging.INFO)


_BASE_PATH = Path(os.getcwd()).resolve()
_HOME_PATH = Path.home()
_CONFIG_PATH = _HOME_PATH / '.config' / 'bs_repoman'
_CACHE_PATH = _HOME_PATH / '.cache' / 'bs_repoman'


@click.group()
def cli():
    """Helps to eliminate repo boilerplate stuff."""
    logger.info("Starting bs_repoman...")
    ensure_path(_CACHE_PATH, 'cache')
    ensure_path(_CONFIG_PATH, 'config')


@cli.command()
@click.option('--language', default="python", help="Install github boilerplate.")
def install_github_template(language: str) -> None:
    click.echo('Initializing github issue templates.')
    _github_template_path = _CACHE_PATH / 'bs-repoman-github-templates'
    if not _github_template_path.exists():
        logger.info("Did not find repo at %s. Cloning bs-repoman-github-templates...", _github_template_path)
        os.system(f'git clone git@github.com:BillSchumacher/bs-repoman-github-templates.git {_github_template_path}')
        logger.info("Cloned bs-repoman-github-templates... to %s", _github_template_path)

    _github_template_path_all = _github_template_path / 'all'
    if language == "python":
        _github_template_path_specific = _github_template_path / 'python'
    else:
        raise NotImplementedError(f"Language {language} not implemented.")

    copytree(_github_template_path_all, _BASE_PATH, dirs_exist_ok=True)
    copytree(_github_template_path_specific, _BASE_PATH, dirs_exist_ok=True)
    logger.info("Copied github templates to %s", _BASE_PATH)



from os.path import exists
from setuptools import setup

setup(
    name='bs-repoman',
    author="Bill Schumacher",
    author_email="34168009+BillSchumacher@users.noreply.github.com",
    version='0.1.0',
    py_modules=['bs_repoman'],
    install_requires=[
        'Click',
        'bs-pathutils',
    ],
    entry_points={
        'console_scripts': [
            'bs_repoman = repoman:cli',
        ],
    },
    scripts=[
        'bs_repoman/scripts/repoman.py',
    ],
    url="https://github.com/BillSchumacher/bs-repoman",
    license="MIT",
    description="My new package.",
    long_description=open("README.md").read() if exists("README.md") else "",
    long_description_content_type='text/markdown',
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.10",
        "Topic :: Software Development :: Libraries",
    ],
)
